@@ -1,5 +1,5 @@
 from typing import Optional, Sequence
-from datetime import date, datetime
+from datetime import date
 from pydantic import BaseModel
 
 from nav_dcat import doc_fields
@@ -31,3 +31,5 @@ class ESDocument(BaseModel):
     publisher: Optional[dict] = {"name": "NAV"}
     license: Optional[dict] = {}
     rights: Optional[str] = f"Copyright {date.today().year}, NAV"
+    content: Optional[dict] = {}
+    url: Optional[str] = ""
